from pyasic.miners.backends import M3X
from pyasic.miners.device.models import M32V10


class BTMinerM32V10(M3X, M32V10):
    pass


from pyasic.miners.device.models import M32V20


class BTMinerM32V20(M3X, M32V20):
    pass
