from pyasic.device.algorithm import MinerAlgo
from pyasic.device.models import MinerModel
from pyasic.miners.device.makes import WhatsMinerMake


class M30SPlusPlusV10(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusV10

    expected_chips = 255
    expected_fans = 2
    expected_hashboards = 4
    algo = MinerAlgo.SHA256


class M30SPlusPlusV20(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusV20

    expected_chips = 255
    expected_fans = 2
    expected_hashboards = 4
    algo = MinerAlgo.SHA256


class M30SPlusPlusVE30(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVE30

    expected_chips = 215
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVE40(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVE40

    expected_chips = 225
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVE50(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVE50

    expected_chips = 235
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVF40(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVF40

    expected_chips = 156
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVG30(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVG30

    expected_chips = 111
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVG40(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVG40

    expected_chips = 117
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVG50(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVG50

    expected_chips = 123
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVH10(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVH10

    expected_chips = 82
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVH100(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVH100

    expected_chips = 82
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVH110(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVH110

    expected_chips = 105
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVH20(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVH20

    expected_chips = 86
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVH30(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVH30

    expected_chips = 111
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVH40(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVH40

    expected_chips = 70
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVH50(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVH50

    expected_chips = 74
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVH60(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVH60

    expected_chips = 78
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVH70(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVH70

    expected_chips = 70
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVH80(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVH80

    expected_chips = 74
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVH90(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVH90

    expected_chips = 78
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVI30(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVI30

    expected_chips = 111
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVJ20(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVJ20

    expected_chips = 70
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVJ30(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVJ30

    expected_chips = 74
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVJ50(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVJ50

    expected_chips = 82
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVJ60(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVJ60

    expected_chips = 111
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVJ70(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVJ70

    expected_chips = 117
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256


class M30SPlusPlusVK30(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVK30

    expected_chips = 74
    expected_fans = 2
    expected_hashboards = 2
    algo = MinerAlgo.SHA256


class M30SPlusPlusVK40(WhatsMinerMake):
    raw_model = MinerModel.WHATSMINER.M30SPlusPlusVK40

    expected_chips = 105
    expected_fans = 2
    expected_hashboards = 3
    algo = MinerAlgo.SHA256
