from pyasic.miners.backends import M6X
from pyasic.miners.device.models import M63VK10


class BTMinerM63VK10(M6X, M63VK10):
    pass


from pyasic.miners.device.models import M63VK20


class BTMinerM63VK20(M6X, M63VK20):
    pass


from pyasic.miners.device.models import M63VK30


class BTMinerM63VK30(M6X, M63VK30):
    pass


from pyasic.miners.device.models import M63VL10


class BTMinerM63VL10(M6X, M63VL10):
    pass


from pyasic.miners.device.models import M63VL30


class BTMinerM63VL30(M6X, M63VL30):
    pass
