from pyasic.miners.backends import M6X
from pyasic.miners.device.models import M61VK10


class BTMinerM61VK10(M6X, M61VK10):
    pass


from pyasic.miners.device.models import M61VK20


class BTMinerM61VK20(M6X, M61VK20):
    pass


from pyasic.miners.device.models import M61VK30


class BTMinerM61VK30(M6X, M61VK30):
    pass


from pyasic.miners.device.models import M61VK40


class BTMinerM61VK40(M6X, M61VK40):
    pass


from pyasic.miners.device.models import M61VL10


class BTMinerM61VL10(M6X, M61VL10):
    pass


from pyasic.miners.device.models import M61VL30


class BTMinerM61VL30(M6X, M61VL30):
    pass


from pyasic.miners.device.models import M61VL40


class BTMinerM61VL40(M6X, M61VL40):
    pass


from pyasic.miners.device.models import M61VL50


class BTMinerM61VL50(M6X, M61VL50):
    pass


from pyasic.miners.device.models import M61VL60


class BTMinerM61VL60(M6X, M61VL60):
    pass
