from pyasic.miners.backends import M3X
from pyasic.miners.device.models import M31V10


class BTMinerM31V10(M3X, M31V10):
    pass


from pyasic.miners.device.models import M31V20


class BTMinerM31V20(M3X, M31V20):
    pass
