from pyasic.miners.backends import M6X
from pyasic.miners.device.models import M66SPlusVK30


class BTMinerM66SPlusVK30(M6X, M66SPlusVK30):
    pass


from pyasic.miners.device.models import M66SPlusVL10


class BTMinerM66SPlusVL10(M6X, M66SPlusVL10):
    pass


from pyasic.miners.device.models import M66SPlusVL20


class BTMinerM66SPlusVL20(M6X, M66SPlusVL20):
    pass


from pyasic.miners.device.models import M66SPlusVL30


class BTMinerM66SPlusVL30(M6X, M66SPlusVL30):
    pass


from pyasic.miners.device.models import M66SPlusVL40


class BTMinerM66SPlusVL40(M6X, M66SPlusVL40):
    pass


from pyasic.miners.device.models import M66SPlusVL60


class BTMinerM66SPlusVL60(M6X, M66SPlusVL60):
    pass
