from pyasic.miners.backends import M5X
from pyasic.miners.device.models import M53VH30


class BTMinerM53VH30(M5X, M53VH30):
    pass


from pyasic.miners.device.models import M53VH40


class BTMinerM53VH40(M5X, M53VH40):
    pass


from pyasic.miners.device.models import M53VH50


class BTMinerM53VH50(M5X, M53VH50):
    pass


from pyasic.miners.device.models import M53VK30


class BTMinerM53VK30(M5X, M53VK30):
    pass


from pyasic.miners.device.models import M53VK60


class BTMinerM53VK60(M5X, M53VK60):
    pass
