from pyasic.miners.backends import M5X
from pyasic.miners.device.models import M50VE30


class BTMinerM50VE30(M5X, M50VE30):
    pass


from pyasic.miners.device.models import M50VG30


class BTMinerM50VG30(M5X, M50VG30):
    pass


from pyasic.miners.device.models import M50VH10


class BTMinerM50VH10(M5X, M50VH10):
    pass


from pyasic.miners.device.models import M50VH20


class BTMinerM50VH20(M5X, M50VH20):
    pass


from pyasic.miners.device.models import M50VH30


class BTMinerM50VH30(M5X, M50VH30):
    pass


from pyasic.miners.device.models import M50VH40


class BTMinerM50VH40(M5X, M50VH40):
    pass


from pyasic.miners.device.models import M50VH50


class BTMinerM50VH50(M5X, M50VH50):
    pass


from pyasic.miners.device.models import M50VH60


class BTMinerM50VH60(M5X, M50VH60):
    pass


from pyasic.miners.device.models import M50VH70


class BTMinerM50VH70(M5X, M50VH70):
    pass


from pyasic.miners.device.models import M50VH80


class BTMinerM50VH80(M5X, M50VH80):
    pass


from pyasic.miners.device.models import M50VH90


class BTMinerM50VH90(M5X, M50VH90):
    pass


from pyasic.miners.device.models import M50VJ10


class BTMinerM50VJ10(M5X, M50VJ10):
    pass


from pyasic.miners.device.models import M50VJ20


class BTMinerM50VJ20(M5X, M50VJ20):
    pass


from pyasic.miners.device.models import M50VJ30


class BTMinerM50VJ30(M5X, M50VJ30):
    pass


from pyasic.miners.device.models import M50VJ40


class BTMinerM50VJ40(M5X, M50VJ40):
    pass


from pyasic.miners.device.models import M50VJ60


class BTMinerM50VJ60(M5X, M50VJ60):
    pass


from pyasic.miners.device.models import M50VK40


class BTMinerM50VK40(M5X, M50VK40):
    pass


from pyasic.miners.device.models import M50VK50


class BTMinerM50VK50(M5X, M50VK50):
    pass
