from pyasic.miners.backends import M3X
from pyasic.miners.device.models import M31SPlusV10


class BTMinerM31SPlusV10(M3X, M31SPlusV10):
    pass


from pyasic.miners.device.models import M31SPlusV100


class BTMinerM31SPlusV100(M3X, M31SPlusV100):
    pass


from pyasic.miners.device.models import M31SPlusV20


class BTMinerM31SPlusV20(M3X, M31SPlusV20):
    pass


from pyasic.miners.device.models import M31SPlusV30


class BTMinerM31SPlusV30(M3X, M31SPlusV30):
    pass


from pyasic.miners.device.models import M31SPlusV40


class BTMinerM31SPlusV40(M3X, M31SPlusV40):
    pass


from pyasic.miners.device.models import M31SPlusV50


class BTMinerM31SPlusV50(M3X, M31SPlusV50):
    pass


from pyasic.miners.device.models import M31SPlusV60


class BTMinerM31SPlusV60(M3X, M31SPlusV60):
    pass


from pyasic.miners.device.models import M31SPlusV80


class BTMinerM31SPlusV80(M3X, M31SPlusV80):
    pass


from pyasic.miners.device.models import M31SPlusV90


class BTMinerM31SPlusV90(M3X, M31SPlusV90):
    pass


from pyasic.miners.device.models import M31SPlusVE10


class BTMinerM31SPlusVE10(M3X, M31SPlusVE10):
    pass


from pyasic.miners.device.models import M31SPlusVE20


class BTMinerM31SPlusVE20(M3X, M31SPlusVE20):
    pass


from pyasic.miners.device.models import M31SPlusVE30


class BTMinerM31SPlusVE30(M3X, M31SPlusVE30):
    pass


from pyasic.miners.device.models import M31SPlusVE40


class BTMinerM31SPlusVE40(M3X, M31SPlusVE40):
    pass


from pyasic.miners.device.models import M31SPlusVE50


class BTMinerM31SPlusVE50(M3X, M31SPlusVE50):
    pass


from pyasic.miners.device.models import M31SPlusVE60


class BTMinerM31SPlusVE60(M3X, M31SPlusVE60):
    pass


from pyasic.miners.device.models import M31SPlusVE80


class BTMinerM31SPlusVE80(M3X, M31SPlusVE80):
    pass


from pyasic.miners.device.models import M31SPlusVF20


class BTMinerM31SPlusVF20(M3X, M31SPlusVF20):
    pass


from pyasic.miners.device.models import M31SPlusVF30


class BTMinerM31SPlusVF30(M3X, M31SPlusVF30):
    pass


from pyasic.miners.device.models import M31SPlusVG20


class BTMinerM31SPlusVG20(M3X, M31SPlusVG20):
    pass


from pyasic.miners.device.models import M31SPlusVG30


class BTMinerM31SPlusVG30(M3X, M31SPlusVG30):
    pass
